@@ -87,7 +87,7 @@ def multiplot(*args, **kwargs):
         if (subplot["data"] is not None):
             # Convert the data to string format:
             if isinstance(subplot["data"], pd.DataFrame):
-                content = subplot["data"].to_csv()
+                content = subplot["data"].to_csv(header=False)
             else:
                 content = str(subplot["data"])
             g.__call__('$DataFrame << EOD\n%s\nEOD' %(content))
@@ -149,7 +149,7 @@ def __gnuplot_data(data, plot_cmd, *args, **kwargs):
 
     # Conver the data to string format:
     if isinstance(data, pd.DataFrame):
-        content = data.to_csv()
+        content = data.to_csv(header=False)
     else:
         content = str(data)
     g.__call__('$DataFrame << EOD\n%s\nEOD' %(content))
@@ -323,7 +323,7 @@ class Gnuplot(object):
         c = 'plot'
 
         if isinstance(data, pd.DataFrame):
-            content = data.to_csv()
+            content = data.to_csv(header=False)
         else:
             content = str(data)
 
@@ -355,7 +355,7 @@ class Gnuplot(object):
         c = 'splot'
 
         if isinstance(data, pd.DataFrame):
-            content = data.to_csv()
+            content = data.to_csv(header=False)
         else:
             content = str(data)
 
